==> xT4aD___2022-12-16_01-59-24.zip: script.js <==

//change icon menu

function changeIcon(menu) {
  menu.classList.toggle("bi-x");
}


//calendar

const date = new Date();

const renderCalender = () => {
	
	date.setDate(1);

	const lastDay = new Date(date.getUTCFullYear(), date.getMonth()+1, 0).getDate();

	const prevLastDay = new Date(date.getUTCFullYear(), date.getMonth(), 0).getDate();
	const firstDayIndex = date.getDay();

	const lastDayIndex = new Date(date.getUTCFullYear(), date.getMonth()+1, 0).getDay();
	const nextDays = 7 - lastDayIndex - 1;

	const months = [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December",
	];
	const year = date.getUTCFullYear();

	const calender = document.querySelectorAll(".calender");

	for (let a=0; a < calender.length; a++) {

		calender[a].querySelector(".current").innerHTML = months[date.getMonth()] + ' '+ year;
		
		const monthDays = calender[a].querySelector(".dates");
		
		let days="";

		for(let x = firstDayIndex; x > 0; x--) {
		days += `<div class="prev-date">${prevLastDay - x + 1}</div>`;
		}
		
		for(let i = 1; i <= lastDay; i++) {

			if( i === new Date().getDate() && date.getMonth() === new Date().getMonth() ) {
				days += `<div class="date today">${i}</div>`;
			} else {
				days += `<div class="date">${i}</div>`;
			}		
		}

		for(let y = 1; y <= nextDays; y++) {
			days += `<div class="next-date">${y}</div>`;			
		}
		monthDays.innerHTML = days;


		//change month
		calender[a].querySelector(".prev-month").addEventListener("click", () => {
			date.setMonth(date.getMonth()-1);
			renderCalender();
		});

		calender[a].querySelector(".next-month").addEventListener("click", () => {
			date.setMonth(date.getMonth()+1);
			renderCalender();
		});
	};
}

renderCalender();

// Add active class to the current button (highlight it)
	let sectionHours = document.getElementById("sectionHours");
	let hourBox = sectionHours.getElementsByClassName("hourBox");

	for (let i = 0; i < hourBox.length; i++) {

		hourBox[i].addEventListener("click", function() {

			let current = document.getElementsByClassName("active");

			if (current.length > 0) { 
				current[0].className = current[0].className.replace(" active", "");
			}

			//i.e. x+=10 => x=x+10
	  		this.className += " active";

		});
	};



	//popovers
	var popoverTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="popover"]'))
	
	var popoverList = popoverTriggerList.map(function (popoverTriggerEl) {
		return new bootstrap.Popover(popoverTriggerEl)
	});

	//popover dismiss
	var popover = new bootstrap.Popover(document.querySelector('.popover-dismiss'), {
	  trigger: 'focus'
	});

==> xT4aD___2022-12-16_02-00-31.zip: script.js <==
//  MENU TOGGLE
//--------------

const toggle = document.querySelector(".toggle");
const menu = document.querySelector(".top-navbar");
const items = document.querySelectorAll(".menu-item");

/* Toggle mobile menu */
function toggleMenu() {
  if (menu.classList.contains("active")) {
    menu.classList.remove("active");
    toggle.querySelector("a").innerHTML = "<i class='bi bi-list'></i>";
  } else {
    menu.classList.add("active");
    toggle.querySelector("a").innerHTML = "<i class='bi bi-x'></i>";
  }
}

/* Event Listeners */
toggle.addEventListener("click", toggleMenu, false);

























//  CALENDER
//-----------

const date = new Date();

const renderCalender = () => {
	
	date.setDate(1);

	const lastDay = new Date(date.getUTCFullYear(), date.getMonth()+1, 0).getDate();

	const prevLastDay = new Date(date.getUTCFullYear(), date.getMonth(), 0).getDate();
	const firstDayIndex = date.getDay();

	const lastDayIndex = new Date(date.getUTCFullYear(), date.getMonth()+1, 0).getDay();
	const nextDays = 7 - lastDayIndex - 1;

	const months = [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December",
	];
	const year = date.getUTCFullYear();

	const calender = document.querySelectorAll(".calender");

	for (let a=0; a < calender.length; a++) {

		calender[a].querySelector(".current").innerHTML = months[date.getMonth()] + ' '+ year;
		
		const monthDays = calender[a].querySelector(".dates");
		
		let days="";

		for(let x = firstDayIndex; x > 0; x--) {
		days += `<div class="prev-date">${prevLastDay - x + 1}</div>`;
		}
		
		for(let i = 1; i <= lastDay; i++) {

			if( i === new Date().getDate() && date.getMonth() === new Date().getMonth() ) {
				days += `<div class="date today" onclick="onClick(this)">${i}</div>`;
			} else {
				days += `<div class="date" onclick="onClick(this)">${i}</div>`;
			}		
		}

		for(let y = 1; y <= nextDays; y++) {
			days += `<div class="next-date">${y}</div>`;			
		}
		monthDays.innerHTML = days;


		//change month
		calender[a].querySelector(".prev-month").addEventListener("click", () => {
			date.setMonth(date.getMonth()-1);
			renderCalender();
		});

		calender[a].querySelector(".next-month").addEventListener("click", () => {
			date.setMonth(date.getMonth()+1);
			renderCalender();
		});

	};
}

renderCalender();

// function onClick($this) {
// 	var val = $this.innerHTML;
 
//   console.log(val);
// }


//  MODAL - TABLE WITH HOURS
//--------------------------


// Add active class to the current button (highlight it)
	let sectionHours = document.getElementById("sectionHours");
	let hourBox = sectionHours.getElementsByClassName("hourBox");

	for (let i = 0; i < hourBox.length; i++) {

		hourBox[i].addEventListener("click", function() {

			let current = document.getElementsByClassName("active");

			if (current.length > 0) { 
				current[0].className = current[0].className.replace(" active", "");
			}

			//i.e. x+=10 => x=x+10
	  		this.className += " active";

		});
	};



// //  POPOVER
// //--------------------------

// 	var popoverTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="popover"]'))
	
// 	var popoverList = popoverTriggerList.map(function (popoverTriggerEl) {
// 		return new bootstrap.Popover(popoverTriggerEl)
// 	});

// //popover dismiss
// 	var popover = new bootstrap.Popover(document.querySelector('.popover-dismiss'), {
// 	  trigger: 'focus'
// 	});
